summaryrefslogtreecommitdiffstats
path: root/halimpl
diff options
context:
space:
mode:
authorRuchi Kandoi <kandoiruchi@google.com>2017-07-06 01:24:42 +0000
committerandroid-build-merger <android-build-merger@google.com>2017-07-06 01:24:42 +0000
commit019e66b00bfe07a20b7e900758dbcf5c7d3027fb (patch)
treef59682320747eb4eb1e4a04d520b3e3f63972070 /halimpl
parent5dddff25e09f92200bbe11e4e73d1a5114826bcc (diff)
parentc8b9c065b2590905f43c4a38ec516a4fd90a28c4 (diff)
downloadandroid_hardware_broadcom_nfc-019e66b00bfe07a20b7e900758dbcf5c7d3027fb.tar.gz
android_hardware_broadcom_nfc-019e66b00bfe07a20b7e900758dbcf5c7d3027fb.tar.bz2
android_hardware_broadcom_nfc-019e66b00bfe07a20b7e900758dbcf5c7d3027fb.zip
Increase write error retry delay from 1ms to 10ms
am: c8b9c065b2 Change-Id: Ifd599ced43305099075d47044cad5d0835eb959f
Diffstat (limited to 'halimpl')
-rw-r--r--halimpl/pn54x/hal/phNxpNciHal.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/halimpl/pn54x/hal/phNxpNciHal.c b/halimpl/pn54x/hal/phNxpNciHal.c
index 978be4f..57fbab4 100644
--- a/halimpl/pn54x/hal/phNxpNciHal.c
+++ b/halimpl/pn54x/hal/phNxpNciHal.c
@@ -859,8 +859,8 @@ retry:
if (nxpncihal_ctrl.retry_cnt++ < MAX_RETRY_COUNT) {
NXPLOG_NCIHAL_E(
"write_unlocked failed - PN54X Maybe in Standby Mode - Retry");
- /* 1ms delay to give NFCC wake up delay */
- usleep(1000);
+ /* 10ms delay to give NFCC wake up delay */
+ usleep(1000 * 10);
goto retry;
} else {
NXPLOG_NCIHAL_E(